@@ -74,7 +74,7 @@
 #include "mapslistview.h"
 #include "kimecommon.h"
 #include "imagemapchoosedialog.h"
-#include "version.h"
+#include "kimagemapeditor_version.h"
 
 K_PLUGIN_FACTORY(KImageMapEditorFactory, registerPlugin<KImageMapEditor>();)
 
@@ -83,7 +83,7 @@ KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
   : KParts::ReadWritePart(parent)
 {
   KAboutData aboutData( "kimagemapeditor", i18n("KImageMapEditor"),
-              KIMAGEMAPEDITOR_VERSION, i18n( "An HTML imagemap editor" ),
+              KIMAGEMAPEDITOR_VERSION_STRING, i18n( "An HTML imagemap editor" ),
               KAboutLicense::GPL,
               i18n("(c) 2001-2003 Jan Sch&auml;fer <email>janschaefer@users.sourceforge.net</email>"));
   setComponentData(aboutData, false);
@@ -1431,7 +1431,7 @@ void KImageMapEditor::setMapName(const QString & s) {
 
 void KImageMapEditor::setPicture(const QUrl & url) {
   _imageUrl=url;
-  if (QFileInfo(url.path()).exists()) {
+  if (QFileInfo::exists(url.path())) {
      QImage img(url.path());
 
      if (!img.isNull()) {
@@ -1656,8 +1656,6 @@ void KImageMapEditor::fileSaveAs() {
   }
 
 
-  QFileInfo fileInfo(url.path());
-
   saveAs(url);
   recentFilesAction->addUrl(url);
 
@@ -1860,7 +1858,6 @@ bool KImageMapEditor::openHTMLFile(const QUrl & url)
       return false;
   f.open(QIODevice::ReadOnly);
   QTextStream s(&f);
-  QString str;
   QChar w;
   QHash<QString,QString> *attr=0L;
   QList<ImageTag*> images;
@@ -2369,8 +2366,6 @@ static QUrl toRelative(const QUrl& urlToConvert,const QUrl& baseURL)
 
 void KImageMapEditor::saveImageMap(const QUrl & url)
 {
-  QFileInfo fileInfo(url.path());
-
   if (!QFileInfo(url.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path()).isWritable()) {
     KMessageBox::error(widget(),
       i18n("<qt>The file <i>%1</i> could not be saved, because you do not have the required write permissions.</qt>", url.path()));
